@@ -1,4 +1,4 @@
-from .SimConnect import SimConnect, Request, millis, DWORD
+from .SimConnect import SimConnect, Request, Event, millis, DWORD
 from .Entities import Plane
 
 
@@ -9,7 +9,7 @@ def int_or_str(value):
 		return value
 
 
-__version__ = "0.3.1"
+__version__ = "0.3.2"
 VERSION = tuple(map(int_or_str, __version__.split(".")))
 
-__all__ = ["SimConnect", "Request", "millis", "DWORD", "Plane"]
+__all__ = ["SimConnect", "Request", "Event", "millis", "DWORD", "Plane"]
